import 'package:ametory_ui/ametory_ui.dart';
import 'package:ametory_ui/src/styles/color.dart';
import 'package:ametory_ui/src/utils/helper/layout.dart';
import 'package:ametory_ui/src/widgets/widget_size.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:google_sign_in/google_sign_in.dart';

class MyLoginPage extends StatefulWidget {
  final Function(UserCredential)? onSubmitGoogle;
  final Color? backgroundColor;
  final Color? boxColor;
  final BorderRadius? boxRadius;
  final Widget? title;
  final Widget? subtitle;
  final Widget? footer;
  final List<BoxShadow>? boxShadow;
  final double? boxWidth;
  final double? boxHeight;
  final TextEditingController? emailController;
  final TextEditingController? passwordController;
  final Function()? onSubmit;
  MyLoginPage(
      {Key? key,
      this.boxWidth,
      this.backgroundColor,
      this.boxColor,
      this.boxRadius,
      this.boxShadow,
      this.title,
      this.subtitle,
      this.boxHeight,
      this.onSubmit,
      this.onSubmitGoogle,
      this.footer,
      this.emailController,
      this.passwordController})
      : super(key: key);

  @override
  State<MyLoginPage> createState() => _MyLoginPageState();
}

class _MyLoginPageState extends State<MyLoginPage> {
  double? width;
  double? height;
  final _key = GlobalKey();
  bool obscureText = true;

// This function is trggered somehow after build() called
  @override
  Widget build(BuildContext context) {
    return Container(
      width: double.infinity,
      height: double.infinity,
      decoration: BoxDecoration(
          color: widget.backgroundColor ?? MyColor.info,
          gradient: LinearGradient(colors: [
            MyColor.info,
            MyColor.info.shade100,
          ], begin: Alignment.topCenter, end: Alignment.bottomCenter)),
      child: Container(
        padding:
            EdgeInsets.all(ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
        alignment: Alignment.center,
        child: WidgetSize(
          onChange: (Size size) {
            width = size.width;
            height = size.height;
            setState(() {});
          },
          child: Container(
              decoration: BoxDecoration(
                  boxShadow: widget.boxShadow ??
                      [const BoxShadow(color: Colors.black45, blurRadius: 10)],
                  color: widget.boxColor ?? Colors.white,
                  borderRadius: widget.boxRadius ?? BorderRadius.circular(10)),
              padding: EdgeInsets.all(
                  ResponsiveWidget.isSmallScreen(context) ? 20 : 40),
              width: ResponsiveWidget.isSmallScreen(context)
                  ? double.infinity
                  : widget.boxWidth ?? 400,
              // height: widget.boxHeight ?? MediaQuery.of(context).size.height,
              child: SingleChildScrollView(
                child: Column(
                  children: [
                    widget.title ??
                        Text(
                          "Login",
                          style: MyTypo.heading1,
                        ),
                    vspace(10),
                    widget.subtitle ?? Container(),
                    vspace(40),
                    Input(
                      keyboardType: TextInputType.emailAddress,
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 6 : 0,
                                    child: Text(
                                      "Email",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.emailController,
                      hintText: "Email",
                      padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                    ),
                    vspace(20),
                    Input(
                      obscureText: obscureText,
                      leading: !ResponsiveWidget.isLargeScreen(context)
                          ? null
                          : SizedBox(
                              child: Row(
                                children: [
                                  SizedBox(
                                    width: width != null ? width! / 6 : 0,
                                    child: Text(
                                      "Password",
                                      style: MyTypo.heading4.copyWith(
                                          fontSize: 12, color: Colors.black54),
                                    ),
                                  ),
                                  hspace(10)
                                ],
                              ),
                            ),
                      controller: widget.passwordController,
                      hintText: "Password",
                      padding: const EdgeInsets.fromLTRB(10, 0, 10, 0),
                      trailing: InkWell(
                        onTap: () => setState(() => obscureText = !obscureText),
                        child: const Icon(
                          Icons.remove_red_eye_outlined,
                          size: 16,
                          color: Colors.black38,
                        ),
                      ),
                    ),
                    widget.footer ?? Container(),
                    vspace(80),
                    SizedBox(
                      width: 200,
                      child: TextButton(
                          onPressed: widget.onSubmit,
                          style: MyStyle.buttonDefault,
                          child: Text(
                            "Login",
                            style: MyTypo.whiteColor,
                          )),
                    ),
                    vspace(20),
                    SizedBox(
                        width: 200,
                        child: TextButton.icon(
                            onPressed: () async {
                              try {
                                // await FirebaseAuth.instance.signOut();
                                final user = await signInWithGoogle();
                                if (widget.onSubmitGoogle != null) {
                                  widget.onSubmitGoogle!(user);
                                }
                              } catch (e) {
                                print("ERROR $e");
                              }
                            },
                            icon: Image.network(
                                width: 20,
                                'https://upload.wikimedia.org/wikipedia/commons/archive/5/53/20190925201609%21Google_%22G%22_Logo.svg'),
                            label: Text("Login By Google"),
                            style: MyStyle.buttonWhite))
                  ],
                ),
              )),
        ),
      ),
    );
  }

  Future<UserCredential> signInWithGoogle() async {
    // Trigger the authentication flow
    final GoogleSignInAccount? googleUser = await GoogleSignIn().signIn();

    // Obtain the auth details from the request
    final GoogleSignInAuthentication? googleAuth =
        await googleUser?.authentication;

    // Create a new credential
    final credential = GoogleAuthProvider.credential(
      accessToken: googleAuth?.accessToken,
      idToken: googleAuth?.idToken,
    );

    // Once signed in, return the UserCredential
    return await FirebaseAuth.instance.signInWithCredential(credential);
  }
}
