import 'package:ametory_ui/src/models/menu_model.dart';
import 'package:ametory_ui/src/styles/typo.dart';
import 'package:flutter/material.dart';

import '../models/main_menu_model.dart';
import '../utils/helper/layout.dart';

class MainMenu extends StatefulWidget {
  final List<MenuModel> menu;
  bool isCollapsed;
  bool isCollapsing;
  double iconWidth;
  final Color? sidebarActiveMenuColor;
  final bool showLabelCollapsed;
  MainMenu(
      {Key? key,
      required this.menu,
      this.showLabelCollapsed = false,
      this.iconWidth = 60,
      this.sidebarActiveMenuColor,
      this.isCollapsed = false,
      this.isCollapsing = false})
      : super(key: key);

  @override
  State<MainMenu> createState() => _MainMenuState();
}

class _MainMenuState extends State<MainMenu> {
  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: widget.menu.map((e) {
        if (e is MainMenuModel) {
          Widget icon = e.icon!;
          if (widget.showLabelCollapsed &&
              e.label != null &&
              (widget.isCollapsed || widget.isCollapsing)) {
            icon = Column(
              children: [e.icon!, vspace(5), e.label!],
            );
          }
          return Container(
            color: e.isActive
                ? (widget.sidebarActiveMenuColor ??
                    Colors.black.withOpacity(0.03))
                : null,
            child: InkWell(
              onTap: e.onTap,
              child: Tooltip(
                waitDuration: const Duration(milliseconds: 1500),
                verticalOffset: 0,
                message: e.tooltip,
                child: Padding(
                  padding:
                      e.padding ?? const EdgeInsets.symmetric(vertical: 10),
                  child: Row(
                    children: [
                      if (e.icon != null)
                        Container(width: widget.iconWidth, child: icon),
                      if (!widget.isCollapsed && !widget.isCollapsing)
                        hspace(5),
                      if (!widget.isCollapsed && !widget.isCollapsing)
                        Expanded(child: e.menu!),
                      if (!widget.isCollapsed && !widget.isCollapsing)
                        hspace(5),
                      if (!widget.isCollapsed &&
                          !widget.isCollapsing &&
                          e.actions != null)
                        Row(
                          children: e.actions!,
                        ),
                      if (!widget.isCollapsed && !widget.isCollapsing)
                        hspace(10),
                    ],
                  ),
                ),
              ),
            ),
          );
        }
        return Container();
      }).toList(),
    );
  }
}
